# agodzoYTRenderer is a python package that allows you to render Youtube videos in your Jupyter Notebook.
# Example Code:


```
from agodzoYTRenderer import render_YouTube_video
```

```
URL = https://www.youtube.com/watch?v=4HOs2cApb90
render_Youtube_video(URL)
```